/*
  Project: SD card module, Vibration sensor module, active piezo buzzer, digital and analog signals. Comment lines if you do not need digital or analog
  Function: If Arduino get 0 (no vibration) from vibration
           sensor it will turn on green LED and turn off Red LED.
           If Arduino get 1 from vibration sensor, it will turn
           on Red LED and turn off green LED.This sketch saves vibration readings to SD card
           Active piezo buzzer will be activated if vibration level will be more then 100.
*/
//****************************************************************
#include <SPI.h> //include library code -for the SD card module
#include <SD.h> //include library code - for the SD card
//****************************************************************
// change this to match your SD shield or module;
// Arduino Ethernet shield and modules: pin 4
// Data loggin SD shields and modules: pin 10
// Sparkfun SD shield: pin 8
const int chipSelect = 4;
File myFile;//create a file to store the data
const int vibrdigPin = 7; //vibration sensor module digital pin attached to digital pin 7 of Arduino
const int greenPin = 5; //Green LED attached to digital pin 5 of Arduino
const int redPin = 6; //Red LED attached to digital pin 6 of Arduino
const int vibraPin = A0; //vibration sensor module analog pin attached to analog pin A0 of Arduino
const int buzzerPin = 8;//active piezo buzzer attached to digital pin 8 of Arduino
int threshold = 5; //sets level of vibration
//****************************************************************
void setup() {
  pinMode(buzzerPin, OUTPUT);
  pinMode(vibrdigPin, INPUT);
  pinMode(vibraPin, INPUT);
  pinMode(greenPin, OUTPUT);
  pinMode(redPin, OUTPUT);
  Serial.begin(9600);//initialize serial communication at 9600 bps
  Serial.print("Initializing SD card...");//setup for the SD card
  if (!SD.begin(chipSelect)) {
    Serial.println("initialization failed!");
    return;
  }
  Serial.println("initialization done.");
  myFile = SD.open("DATA.txt", FILE_WRITE); //opens file
  if (myFile) { //if the file opened ok, writes to it
    Serial.println("File opened ok");
    myFile.println("Sensor Status, Vibration level");//prints the headings for our data
  }
  myFile.close();
}
//************************************************************
void loggingVibration() {
  int dvalue = digitalRead(vibrdigPin); //reads the digital value from vibration sensor module
  int avalue = analogRead(vibraPin); //reads the analog value from vibration sensor module
  int analogvalue = map(avalue, 0, 1023, 0, 10);//maps the analog value - 10 highest vibration level/0 no vibration
  //debugging purposes
  Serial.print("Sensor status: ");//prints sensor status in serial monitor - 1 (ACTIVE)/0 (STBY)
  Serial.print(dvalue);//prints sensor status in serial monitor
  Serial.print(" ");
  Serial.print("Vibration level: ");//prints sensor value in serial monitor - 10 highest vibration level/0 no vibration
  Serial.println(analogvalue);//prints sensor value in serial monitor
  if (dvalue == 1) //if vibration detected
  {
    digitalWrite(redPin, HIGH); //sets LED on
    digitalWrite(greenPin, LOW); //sets LED off
    //tone(buzzerPin, 500);
    delay(10);//sets delay for 10 ms
  }
  else
  digitalWrite(redPin, LOW); //sets LED off
  digitalWrite(greenPin, HIGH); //sets LED on
 // noTone(buzzerPin);
  if (analogvalue > threshold) //if analog value of vibration more then threshold value
  {
    digitalWrite(redPin, HIGH); //sets LED on
    digitalWrite(greenPin, LOW); //sets LED off
    tone(buzzerPin, 500);//activates the buzzer
    delay(10);//sets delay for 10 ms
  }
  else
  digitalWrite(redPin, LOW); //sets LED off
  digitalWrite(greenPin, HIGH); //sets LED on
  noTone(buzzerPin);
  myFile = SD.open("DATA.txt", FILE_WRITE);
  if (myFile) {
    myFile.print(dvalue);
    myFile.print(","); //Move to next column using a ","
    myFile.print(analogvalue);
    myFile.print(","); //Move to next column using a ","
    myFile.println(); //End of Row move to next row
  }
  myFile.close();
}
//*********************************************************
void loop() {
  loggingVibration();
  delay(200);//sets 200 ms delay between measurements
}

